# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_inventory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_inventory.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dsteammessages_inventory.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"A\n\x1f\x43Inventory_GetInventory_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\"\xbf\x01\n\x13\x43Inventory_Response\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x16\n\x0eremoveditemids\x18\x02 \x03(\x04\x12\x11\n\titem_json\x18\x03 \x01(\t\x12\x14\n\x0citemdef_json\x18\x04 \x01(\t\x12\x0e\n\x06ticket\x18\x05 \x01(\x0c\x12I\n\x08replayed\x18\x06 \x01(\x08\x42\x37\x82\xb5\x18\x33If true, the requestid given was processed earlier.\"\x8e\x01\n\x1f\x43Inventory_ExchangeItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x17\n\x0fmaterialsitemid\x18\x03 \x03(\x04\x12\x19\n\x11materialsquantity\x18\x04 \x03(\r\x12\x17\n\x0foutputitemdefid\x18\x05 \x01(\x04\"O\n-CInventory_GetEligiblePromoItemDefIDs_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\"D\n.CInventory_GetEligiblePromoItemDefIDs_Response\x12\x12\n\nitemdefids\x18\x01 \x03(\x04\"\xcc\x03\n\x1a\x43Inventory_AddItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x03(\x04\x12\x15\n\ritempropsjson\x18\x03 \x03(\t\x12\x0f\n\x07steamid\x18\x04 \x01(\x04\x12\\\n\x06notify\x18\x05 \x01(\x08\x42L\x82\xb5\x18HShould notify the user that the item was added to their Steam Inventory.\x12\x11\n\trequestid\x18\x06 \x01(\x04\x12j\n\x11trade_restriction\x18\x07 \x01(\x08\x42O\x82\xb5\x18KIf true, apply the default trade and market restriction times to this item.\x12\x86\x01\n\x0bis_purchase\x18\x08 \x01(\x08:\x05\x66\x61lseBj\x82\xb5\x18\x66If set, treat requestid as a txnid and create this item as a result of user microtransaction purchase.\"\xe5\x02\n\x1e\x43Inventory_ModifyItems_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x43\n\x07updates\x18\x03 \x03(\x0b\x32\x32.CInventory_ModifyItems_Request.ItemPropertyUpdate\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x1a\xca\x01\n\x12ItemPropertyUpdate\x12\x0e\n\x06itemid\x18\x01 \x01(\x04\x12\x17\n\x0fremove_property\x18\x02 \x01(\x08\x12\x15\n\rproperty_name\x18\x03 \x01(\t\x12\x1b\n\x13property_value_bool\x18\x04 \x01(\x08\x12\x1a\n\x12property_value_int\x18\x05 \x01(\x03\x12\x1d\n\x15property_value_string\x18\x06 \x01(\t\x12\x1c\n\x14property_value_float\x18\x07 \x01(\x02\"F\n\"CInventory_ConsumePlaytime_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x01(\x04\"\x88\x01\n\x1e\x43Inventory_ConsumeItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x11\n\ttimestamp\x18\x04 \x01(\t\x12\x0f\n\x07steamid\x18\x05 \x01(\x04\x12\x11\n\trequestid\x18\x06 \x01(\x04\"W\n!CInventory_DevSetNextDrop_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x01(\x04\x12\x10\n\x08\x64roptime\x18\x03 \x01(\t\"e\n!CInventory_SplitItemStack_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x0f\n\x07steamid\x18\x05 \x01(\x04\"\x80\x01\n$CInventory_CombineItemStacks_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nfromitemid\x18\x02 \x01(\x04\x12\x12\n\ndestitemid\x18\x03 \x01(\x04\x12\x10\n\x08quantity\x18\x04 \x01(\r\x12\x0f\n\x07steamid\x18\x07 \x01(\x06\"2\n!CInventory_GetItemDefMeta_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"F\n\"CInventory_GetItemDefMeta_Response\x12\x10\n\x08modified\x18\x01 \x01(\r\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\"(\n&CInventory_GetUserPurchaseInfo_Request\"<\n\'CInventory_GetUserPurchaseInfo_Response\x12\x11\n\tecurrency\x18\x01 \x01(\x05\"\xb2\x01\n\x1f\x43Inventory_PurchaseInit_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08language\x18\x02 \x01(\x05\x12=\n\nline_items\x18\x03 \x03(\x0b\x32).CInventory_PurchaseInit_Request.LineItem\x1a/\n\x08LineItem\x12\x11\n\titemdefid\x18\x01 \x01(\x04\x12\x10\n\x08quantity\x18\x02 \x01(\r\"D\n CInventory_PurchaseInit_Response\x12\x0f\n\x07orderid\x18\x01 \x01(\x04\x12\x0f\n\x07transid\x18\x02 \x01(\x04\"W\n#CInventory_PurchaseFinalize_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08language\x18\x02 \x01(\x05\x12\x0f\n\x07orderid\x18\x03 \x01(\x04\"Q\n\x1e\x43Inventory_InspectItem_Request\x12\x11\n\titemdefid\x18\x01 \x01(\x04\x12\x0e\n\x06itemid\x18\x02 \x01(\x06\x12\x0c\n\x04tags\x18\x03 \x01(\t\"i\n&CInventoryClient_NewItems_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x30\n\x12inventory_response\x18\x02 \x01(\x0b\x32\x14.CInventory_Response2\xbb\x10\n\tInventory\x12z\n\x0cGetInventory\x12 .CInventory_GetInventory_Request\x1a\x14.CInventory_Response\"2\x82\xb5\x18.Retrieves a users inventory as a big JSON blob\x12o\n\x0c\x45xchangeItem\x12 .CInventory_ExchangeItem_Request\x1a\x14.CInventory_Response\"\'\x82\xb5\x18#Craft an item in a user\'s inventory\x12\xbd\x01\n\x1aGetEligiblePromoItemDefIDs\x12..CInventory_GetEligiblePromoItemDefIDs_Request\x1a/.CInventory_GetEligiblePromoItemDefIDs_Response\">\x82\xb5\x18:Returns a list of promo item defs the user is eligible for\x12n\n\x0c\x41\x64\x64PromoItem\x12\x1b.CInventory_AddItem_Request\x1a\x14.CInventory_Response\"+\x82\xb5\x18\'Adds a promo item to a user\'s inventory\x12\x89\x01\n\x0fSafeModifyItems\x12\x1f.CInventory_ModifyItems_Request\x1a\x14.CInventory_Response\"?\x82\xb5\x18;Modify an item in a user\'s inventory (safe properties only)\x12\x87\x01\n\x0f\x43onsumePlaytime\x12#.CInventory_ConsumePlaytime_Request\x1a\x14.CInventory_Response\"9\x82\xb5\x18\x35\x43onsumes playtime and possibly returns a granted item\x12Y\n\x0b\x43onsumeItem\x12\x1f.CInventory_ConsumeItem_Request\x1a\x14.CInventory_Response\"\x13\x82\xb5\x18\x0f\x43onsume an item\x12n\n\x0f\x44\x65vGenerateItem\x12\x1b.CInventory_AddItem_Request\x1a\x14.CInventory_Response\"(\x82\xb5\x18$Grant an item when in developer mode\x12_\n\x0e\x44\x65vSetNextDrop\x12\".CInventory_DevSetNextDrop_Request\x1a\x14.CInventory_Response\"\x13\x82\xb5\x18\x0f\x43onsume an item\x12s\n\x0eSplitItemStack\x12\".CInventory_SplitItemStack_Request\x1a\x14.CInventory_Response\"\'\x82\xb5\x18#Split an item stack into two stacks\x12q\n\x11\x43ombineItemStacks\x12%.CInventory_CombineItemStacks_Request\x1a\x14.CInventory_Response\"\x1f\x82\xb5\x18\x1b\x43ombine two stacks of items\x12\x9c\x01\n\x0eGetItemDefMeta\x12\".CInventory_GetItemDefMeta_Request\x1a#.CInventory_GetItemDefMeta_Response\"A\x82\xb5\x18=Get metadata about the current item definition for this game.\x12\xa7\x01\n\x13GetUserPurchaseInfo\x12\'.CInventory_GetUserPurchaseInfo_Request\x1a(.CInventory_GetUserPurchaseInfo_Response\"=\x82\xb5\x18\x39Returns information about the user such as their currency\x12|\n\x0cPurchaseInit\x12 .CInventory_PurchaseInit_Request\x1a!.CInventory_PurchaseInit_Response\"\'\x82\xb5\x18#Initializes a purchase for the user\x12u\n\x10PurchaseFinalize\x12$.CInventory_PurchaseFinalize_Request\x1a\x14.CInventory_Response\"%\x82\xb5\x18!Finalizes a purchase for the user\x12x\n\x0bInspectItem\x12\x1f.CInventory_InspectItem_Request\x1a\x14.CInventory_Response\"2\x82\xb5\x18.Get item detail given a valid inspection token\x1a/\x82\xb5\x18+A service that provides access to inventory2\xc4\x01\n\x0fInventoryClient\x12z\n\x0eNotifyNewItems\x12\'.CInventoryClient_NewItems_Notification\x1a\x0b.NoResponse\"2\x82\xb5\x18.Notify client that the user received new items\x1a\x35\x82\xb5\x18-Client notifications inventory service events\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CINVENTORY_GETINVENTORY_REQUEST = _descriptor.Descriptor(
  name='CInventory_GetInventory_Request',
  full_name='CInventory_GetInventory_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_GetInventory_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_GetInventory_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=158,
)


_CINVENTORY_RESPONSE = _descriptor.Descriptor(
  name='CInventory_Response',
  full_name='CInventory_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='etag', full_name='CInventory_Response.etag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removeditemids', full_name='CInventory_Response.removeditemids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_json', full_name='CInventory_Response.item_json', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itemdef_json', full_name='CInventory_Response.itemdef_json', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CInventory_Response.ticket', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replayed', full_name='CInventory_Response.replayed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303If true, the requestid given was processed earlier.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=352,
)


_CINVENTORY_EXCHANGEITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_ExchangeItem_Request',
  full_name='CInventory_ExchangeItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_ExchangeItem_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_ExchangeItem_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialsitemid', full_name='CInventory_ExchangeItem_Request.materialsitemid', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialsquantity', full_name='CInventory_ExchangeItem_Request.materialsquantity', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputitemdefid', full_name='CInventory_ExchangeItem_Request.outputitemdefid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=497,
)


_CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_REQUEST = _descriptor.Descriptor(
  name='CInventory_GetEligiblePromoItemDefIDs_Request',
  full_name='CInventory_GetEligiblePromoItemDefIDs_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_GetEligiblePromoItemDefIDs_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_GetEligiblePromoItemDefIDs_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=578,
)


_CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_RESPONSE = _descriptor.Descriptor(
  name='CInventory_GetEligiblePromoItemDefIDs_Response',
  full_name='CInventory_GetEligiblePromoItemDefIDs_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='itemdefids', full_name='CInventory_GetEligiblePromoItemDefIDs_Response.itemdefids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=648,
)


_CINVENTORY_ADDITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_AddItem_Request',
  full_name='CInventory_AddItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_AddItem_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_AddItem_Request.itemdefid', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itempropsjson', full_name='CInventory_AddItem_Request.itempropsjson', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_AddItem_Request.steamid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notify', full_name='CInventory_AddItem_Request.notify', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030HShould notify the user that the item was added to their Steam Inventory.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requestid', full_name='CInventory_AddItem_Request.requestid', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_restriction', full_name='CInventory_AddItem_Request.trade_restriction', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030KIf true, apply the default trade and market restriction times to this item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_purchase', full_name='CInventory_AddItem_Request.is_purchase', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030fIf set, treat requestid as a txnid and create this item as a result of user microtransaction purchase.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=1111,
)


_CINVENTORY_MODIFYITEMS_REQUEST_ITEMPROPERTYUPDATE = _descriptor.Descriptor(
  name='ItemPropertyUpdate',
  full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate.itemid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_property', full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate.remove_property', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_name', full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate.property_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_value_bool', full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate.property_value_bool', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_value_int', full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate.property_value_int', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_value_string', full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate.property_value_string', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_value_float', full_name='CInventory_ModifyItems_Request.ItemPropertyUpdate.property_value_float', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1471,
)

_CINVENTORY_MODIFYITEMS_REQUEST = _descriptor.Descriptor(
  name='CInventory_ModifyItems_Request',
  full_name='CInventory_ModifyItems_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_ModifyItems_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_ModifyItems_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='CInventory_ModifyItems_Request.updates', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CInventory_ModifyItems_Request.timestamp', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CINVENTORY_MODIFYITEMS_REQUEST_ITEMPROPERTYUPDATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1471,
)


_CINVENTORY_CONSUMEPLAYTIME_REQUEST = _descriptor.Descriptor(
  name='CInventory_ConsumePlaytime_Request',
  full_name='CInventory_ConsumePlaytime_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_ConsumePlaytime_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_ConsumePlaytime_Request.itemdefid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1543,
)


_CINVENTORY_CONSUMEITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_ConsumeItem_Request',
  full_name='CInventory_ConsumeItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_ConsumeItem_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CInventory_ConsumeItem_Request.itemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CInventory_ConsumeItem_Request.quantity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CInventory_ConsumeItem_Request.timestamp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_ConsumeItem_Request.steamid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requestid', full_name='CInventory_ConsumeItem_Request.requestid', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=1682,
)


_CINVENTORY_DEVSETNEXTDROP_REQUEST = _descriptor.Descriptor(
  name='CInventory_DevSetNextDrop_Request',
  full_name='CInventory_DevSetNextDrop_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_DevSetNextDrop_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_DevSetNextDrop_Request.itemdefid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='droptime', full_name='CInventory_DevSetNextDrop_Request.droptime', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1684,
  serialized_end=1771,
)


_CINVENTORY_SPLITITEMSTACK_REQUEST = _descriptor.Descriptor(
  name='CInventory_SplitItemStack_Request',
  full_name='CInventory_SplitItemStack_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_SplitItemStack_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CInventory_SplitItemStack_Request.itemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CInventory_SplitItemStack_Request.quantity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_SplitItemStack_Request.steamid', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1773,
  serialized_end=1874,
)


_CINVENTORY_COMBINEITEMSTACKS_REQUEST = _descriptor.Descriptor(
  name='CInventory_CombineItemStacks_Request',
  full_name='CInventory_CombineItemStacks_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_CombineItemStacks_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromitemid', full_name='CInventory_CombineItemStacks_Request.fromitemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destitemid', full_name='CInventory_CombineItemStacks_Request.destitemid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CInventory_CombineItemStacks_Request.quantity', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_CombineItemStacks_Request.steamid', index=4,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1877,
  serialized_end=2005,
)


_CINVENTORY_GETITEMDEFMETA_REQUEST = _descriptor.Descriptor(
  name='CInventory_GetItemDefMeta_Request',
  full_name='CInventory_GetItemDefMeta_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_GetItemDefMeta_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2007,
  serialized_end=2057,
)


_CINVENTORY_GETITEMDEFMETA_RESPONSE = _descriptor.Descriptor(
  name='CInventory_GetItemDefMeta_Response',
  full_name='CInventory_GetItemDefMeta_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modified', full_name='CInventory_GetItemDefMeta_Response.modified', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digest', full_name='CInventory_GetItemDefMeta_Response.digest', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2059,
  serialized_end=2129,
)


_CINVENTORY_GETUSERPURCHASEINFO_REQUEST = _descriptor.Descriptor(
  name='CInventory_GetUserPurchaseInfo_Request',
  full_name='CInventory_GetUserPurchaseInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2131,
  serialized_end=2171,
)


_CINVENTORY_GETUSERPURCHASEINFO_RESPONSE = _descriptor.Descriptor(
  name='CInventory_GetUserPurchaseInfo_Response',
  full_name='CInventory_GetUserPurchaseInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ecurrency', full_name='CInventory_GetUserPurchaseInfo_Response.ecurrency', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2173,
  serialized_end=2233,
)


_CINVENTORY_PURCHASEINIT_REQUEST_LINEITEM = _descriptor.Descriptor(
  name='LineItem',
  full_name='CInventory_PurchaseInit_Request.LineItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_PurchaseInit_Request.LineItem.itemdefid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CInventory_PurchaseInit_Request.LineItem.quantity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2367,
  serialized_end=2414,
)

_CINVENTORY_PURCHASEINIT_REQUEST = _descriptor.Descriptor(
  name='CInventory_PurchaseInit_Request',
  full_name='CInventory_PurchaseInit_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_PurchaseInit_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CInventory_PurchaseInit_Request.language', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_items', full_name='CInventory_PurchaseInit_Request.line_items', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CINVENTORY_PURCHASEINIT_REQUEST_LINEITEM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2236,
  serialized_end=2414,
)


_CINVENTORY_PURCHASEINIT_RESPONSE = _descriptor.Descriptor(
  name='CInventory_PurchaseInit_Response',
  full_name='CInventory_PurchaseInit_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orderid', full_name='CInventory_PurchaseInit_Response.orderid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transid', full_name='CInventory_PurchaseInit_Response.transid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2416,
  serialized_end=2484,
)


_CINVENTORY_PURCHASEFINALIZE_REQUEST = _descriptor.Descriptor(
  name='CInventory_PurchaseFinalize_Request',
  full_name='CInventory_PurchaseFinalize_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_PurchaseFinalize_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='CInventory_PurchaseFinalize_Request.language', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderid', full_name='CInventory_PurchaseFinalize_Request.orderid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2486,
  serialized_end=2573,
)


_CINVENTORY_INSPECTITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_InspectItem_Request',
  full_name='CInventory_InspectItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_InspectItem_Request.itemdefid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CInventory_InspectItem_Request.itemid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CInventory_InspectItem_Request.tags', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2575,
  serialized_end=2656,
)


_CINVENTORYCLIENT_NEWITEMS_NOTIFICATION = _descriptor.Descriptor(
  name='CInventoryClient_NewItems_Notification',
  full_name='CInventoryClient_NewItems_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventoryClient_NewItems_Notification.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inventory_response', full_name='CInventoryClient_NewItems_Notification.inventory_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2658,
  serialized_end=2763,
)

_CINVENTORY_MODIFYITEMS_REQUEST_ITEMPROPERTYUPDATE.containing_type = _CINVENTORY_MODIFYITEMS_REQUEST
_CINVENTORY_MODIFYITEMS_REQUEST.fields_by_name['updates'].message_type = _CINVENTORY_MODIFYITEMS_REQUEST_ITEMPROPERTYUPDATE
_CINVENTORY_PURCHASEINIT_REQUEST_LINEITEM.containing_type = _CINVENTORY_PURCHASEINIT_REQUEST
_CINVENTORY_PURCHASEINIT_REQUEST.fields_by_name['line_items'].message_type = _CINVENTORY_PURCHASEINIT_REQUEST_LINEITEM
_CINVENTORYCLIENT_NEWITEMS_NOTIFICATION.fields_by_name['inventory_response'].message_type = _CINVENTORY_RESPONSE
DESCRIPTOR.message_types_by_name['CInventory_GetInventory_Request'] = _CINVENTORY_GETINVENTORY_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_Response'] = _CINVENTORY_RESPONSE
DESCRIPTOR.message_types_by_name['CInventory_ExchangeItem_Request'] = _CINVENTORY_EXCHANGEITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_GetEligiblePromoItemDefIDs_Request'] = _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_GetEligiblePromoItemDefIDs_Response'] = _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_RESPONSE
DESCRIPTOR.message_types_by_name['CInventory_AddItem_Request'] = _CINVENTORY_ADDITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_ModifyItems_Request'] = _CINVENTORY_MODIFYITEMS_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_ConsumePlaytime_Request'] = _CINVENTORY_CONSUMEPLAYTIME_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_ConsumeItem_Request'] = _CINVENTORY_CONSUMEITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_DevSetNextDrop_Request'] = _CINVENTORY_DEVSETNEXTDROP_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_SplitItemStack_Request'] = _CINVENTORY_SPLITITEMSTACK_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_CombineItemStacks_Request'] = _CINVENTORY_COMBINEITEMSTACKS_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_GetItemDefMeta_Request'] = _CINVENTORY_GETITEMDEFMETA_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_GetItemDefMeta_Response'] = _CINVENTORY_GETITEMDEFMETA_RESPONSE
DESCRIPTOR.message_types_by_name['CInventory_GetUserPurchaseInfo_Request'] = _CINVENTORY_GETUSERPURCHASEINFO_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_GetUserPurchaseInfo_Response'] = _CINVENTORY_GETUSERPURCHASEINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CInventory_PurchaseInit_Request'] = _CINVENTORY_PURCHASEINIT_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_PurchaseInit_Response'] = _CINVENTORY_PURCHASEINIT_RESPONSE
DESCRIPTOR.message_types_by_name['CInventory_PurchaseFinalize_Request'] = _CINVENTORY_PURCHASEFINALIZE_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_InspectItem_Request'] = _CINVENTORY_INSPECTITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventoryClient_NewItems_Notification'] = _CINVENTORYCLIENT_NEWITEMS_NOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CInventory_GetInventory_Request = _reflection.GeneratedProtocolMessageType('CInventory_GetInventory_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_GETINVENTORY_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetInventory_Request)
  })
_sym_db.RegisterMessage(CInventory_GetInventory_Request)

CInventory_Response = _reflection.GeneratedProtocolMessageType('CInventory_Response', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_RESPONSE,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_Response)
  })
_sym_db.RegisterMessage(CInventory_Response)

CInventory_ExchangeItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_ExchangeItem_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_EXCHANGEITEM_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_ExchangeItem_Request)
  })
_sym_db.RegisterMessage(CInventory_ExchangeItem_Request)

CInventory_GetEligiblePromoItemDefIDs_Request = _reflection.GeneratedProtocolMessageType('CInventory_GetEligiblePromoItemDefIDs_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetEligiblePromoItemDefIDs_Request)
  })
_sym_db.RegisterMessage(CInventory_GetEligiblePromoItemDefIDs_Request)

CInventory_GetEligiblePromoItemDefIDs_Response = _reflection.GeneratedProtocolMessageType('CInventory_GetEligiblePromoItemDefIDs_Response', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_RESPONSE,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetEligiblePromoItemDefIDs_Response)
  })
_sym_db.RegisterMessage(CInventory_GetEligiblePromoItemDefIDs_Response)

CInventory_AddItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_AddItem_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_ADDITEM_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_AddItem_Request)
  })
_sym_db.RegisterMessage(CInventory_AddItem_Request)

CInventory_ModifyItems_Request = _reflection.GeneratedProtocolMessageType('CInventory_ModifyItems_Request', (_message.Message,), {

  'ItemPropertyUpdate' : _reflection.GeneratedProtocolMessageType('ItemPropertyUpdate', (_message.Message,), {
    'DESCRIPTOR' : _CINVENTORY_MODIFYITEMS_REQUEST_ITEMPROPERTYUPDATE,
    '__module__' : 'steammessages_inventory_pb2'
    # @@protoc_insertion_point(class_scope:CInventory_ModifyItems_Request.ItemPropertyUpdate)
    })
  ,
  'DESCRIPTOR' : _CINVENTORY_MODIFYITEMS_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_ModifyItems_Request)
  })
_sym_db.RegisterMessage(CInventory_ModifyItems_Request)
_sym_db.RegisterMessage(CInventory_ModifyItems_Request.ItemPropertyUpdate)

CInventory_ConsumePlaytime_Request = _reflection.GeneratedProtocolMessageType('CInventory_ConsumePlaytime_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_CONSUMEPLAYTIME_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_ConsumePlaytime_Request)
  })
_sym_db.RegisterMessage(CInventory_ConsumePlaytime_Request)

CInventory_ConsumeItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_ConsumeItem_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_CONSUMEITEM_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_ConsumeItem_Request)
  })
_sym_db.RegisterMessage(CInventory_ConsumeItem_Request)

CInventory_DevSetNextDrop_Request = _reflection.GeneratedProtocolMessageType('CInventory_DevSetNextDrop_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_DEVSETNEXTDROP_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_DevSetNextDrop_Request)
  })
_sym_db.RegisterMessage(CInventory_DevSetNextDrop_Request)

CInventory_SplitItemStack_Request = _reflection.GeneratedProtocolMessageType('CInventory_SplitItemStack_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_SPLITITEMSTACK_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_SplitItemStack_Request)
  })
_sym_db.RegisterMessage(CInventory_SplitItemStack_Request)

CInventory_CombineItemStacks_Request = _reflection.GeneratedProtocolMessageType('CInventory_CombineItemStacks_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_COMBINEITEMSTACKS_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_CombineItemStacks_Request)
  })
_sym_db.RegisterMessage(CInventory_CombineItemStacks_Request)

CInventory_GetItemDefMeta_Request = _reflection.GeneratedProtocolMessageType('CInventory_GetItemDefMeta_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_GETITEMDEFMETA_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetItemDefMeta_Request)
  })
_sym_db.RegisterMessage(CInventory_GetItemDefMeta_Request)

CInventory_GetItemDefMeta_Response = _reflection.GeneratedProtocolMessageType('CInventory_GetItemDefMeta_Response', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_GETITEMDEFMETA_RESPONSE,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetItemDefMeta_Response)
  })
_sym_db.RegisterMessage(CInventory_GetItemDefMeta_Response)

CInventory_GetUserPurchaseInfo_Request = _reflection.GeneratedProtocolMessageType('CInventory_GetUserPurchaseInfo_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_GETUSERPURCHASEINFO_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetUserPurchaseInfo_Request)
  })
_sym_db.RegisterMessage(CInventory_GetUserPurchaseInfo_Request)

CInventory_GetUserPurchaseInfo_Response = _reflection.GeneratedProtocolMessageType('CInventory_GetUserPurchaseInfo_Response', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_GETUSERPURCHASEINFO_RESPONSE,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetUserPurchaseInfo_Response)
  })
_sym_db.RegisterMessage(CInventory_GetUserPurchaseInfo_Response)

CInventory_PurchaseInit_Request = _reflection.GeneratedProtocolMessageType('CInventory_PurchaseInit_Request', (_message.Message,), {

  'LineItem' : _reflection.GeneratedProtocolMessageType('LineItem', (_message.Message,), {
    'DESCRIPTOR' : _CINVENTORY_PURCHASEINIT_REQUEST_LINEITEM,
    '__module__' : 'steammessages_inventory_pb2'
    # @@protoc_insertion_point(class_scope:CInventory_PurchaseInit_Request.LineItem)
    })
  ,
  'DESCRIPTOR' : _CINVENTORY_PURCHASEINIT_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_PurchaseInit_Request)
  })
_sym_db.RegisterMessage(CInventory_PurchaseInit_Request)
_sym_db.RegisterMessage(CInventory_PurchaseInit_Request.LineItem)

CInventory_PurchaseInit_Response = _reflection.GeneratedProtocolMessageType('CInventory_PurchaseInit_Response', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_PURCHASEINIT_RESPONSE,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_PurchaseInit_Response)
  })
_sym_db.RegisterMessage(CInventory_PurchaseInit_Response)

CInventory_PurchaseFinalize_Request = _reflection.GeneratedProtocolMessageType('CInventory_PurchaseFinalize_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_PURCHASEFINALIZE_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_PurchaseFinalize_Request)
  })
_sym_db.RegisterMessage(CInventory_PurchaseFinalize_Request)

CInventory_InspectItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_InspectItem_Request', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORY_INSPECTITEM_REQUEST,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_InspectItem_Request)
  })
_sym_db.RegisterMessage(CInventory_InspectItem_Request)

CInventoryClient_NewItems_Notification = _reflection.GeneratedProtocolMessageType('CInventoryClient_NewItems_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CINVENTORYCLIENT_NEWITEMS_NOTIFICATION,
  '__module__' : 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventoryClient_NewItems_Notification)
  })
_sym_db.RegisterMessage(CInventoryClient_NewItems_Notification)


DESCRIPTOR._options = None
_CINVENTORY_RESPONSE.fields_by_name['replayed']._options = None
_CINVENTORY_ADDITEM_REQUEST.fields_by_name['notify']._options = None
_CINVENTORY_ADDITEM_REQUEST.fields_by_name['trade_restriction']._options = None
_CINVENTORY_ADDITEM_REQUEST.fields_by_name['is_purchase']._options = None

_INVENTORY = _descriptor.ServiceDescriptor(
  name='Inventory',
  full_name='Inventory',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030+A service that provides access to inventory',
  create_key=_descriptor._internal_create_key,
  serialized_start=2766,
  serialized_end=4873,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInventory',
    full_name='Inventory.GetInventory',
    index=0,
    containing_service=None,
    input_type=_CINVENTORY_GETINVENTORY_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030.Retrieves a users inventory as a big JSON blob',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExchangeItem',
    full_name='Inventory.ExchangeItem',
    index=1,
    containing_service=None,
    input_type=_CINVENTORY_EXCHANGEITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030#Craft an item in a user\'s inventory',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEligiblePromoItemDefIDs',
    full_name='Inventory.GetEligiblePromoItemDefIDs',
    index=2,
    containing_service=None,
    input_type=_CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_REQUEST,
    output_type=_CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_RESPONSE,
    serialized_options=b'\202\265\030:Returns a list of promo item defs the user is eligible for',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddPromoItem',
    full_name='Inventory.AddPromoItem',
    index=3,
    containing_service=None,
    input_type=_CINVENTORY_ADDITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030\'Adds a promo item to a user\'s inventory',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SafeModifyItems',
    full_name='Inventory.SafeModifyItems',
    index=4,
    containing_service=None,
    input_type=_CINVENTORY_MODIFYITEMS_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030;Modify an item in a user\'s inventory (safe properties only)',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConsumePlaytime',
    full_name='Inventory.ConsumePlaytime',
    index=5,
    containing_service=None,
    input_type=_CINVENTORY_CONSUMEPLAYTIME_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\0305Consumes playtime and possibly returns a granted item',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConsumeItem',
    full_name='Inventory.ConsumeItem',
    index=6,
    containing_service=None,
    input_type=_CINVENTORY_CONSUMEITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030\017Consume an item',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DevGenerateItem',
    full_name='Inventory.DevGenerateItem',
    index=7,
    containing_service=None,
    input_type=_CINVENTORY_ADDITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030$Grant an item when in developer mode',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DevSetNextDrop',
    full_name='Inventory.DevSetNextDrop',
    index=8,
    containing_service=None,
    input_type=_CINVENTORY_DEVSETNEXTDROP_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030\017Consume an item',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SplitItemStack',
    full_name='Inventory.SplitItemStack',
    index=9,
    containing_service=None,
    input_type=_CINVENTORY_SPLITITEMSTACK_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030#Split an item stack into two stacks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CombineItemStacks',
    full_name='Inventory.CombineItemStacks',
    index=10,
    containing_service=None,
    input_type=_CINVENTORY_COMBINEITEMSTACKS_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030\033Combine two stacks of items',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetItemDefMeta',
    full_name='Inventory.GetItemDefMeta',
    index=11,
    containing_service=None,
    input_type=_CINVENTORY_GETITEMDEFMETA_REQUEST,
    output_type=_CINVENTORY_GETITEMDEFMETA_RESPONSE,
    serialized_options=b'\202\265\030=Get metadata about the current item definition for this game.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserPurchaseInfo',
    full_name='Inventory.GetUserPurchaseInfo',
    index=12,
    containing_service=None,
    input_type=_CINVENTORY_GETUSERPURCHASEINFO_REQUEST,
    output_type=_CINVENTORY_GETUSERPURCHASEINFO_RESPONSE,
    serialized_options=b'\202\265\0309Returns information about the user such as their currency',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PurchaseInit',
    full_name='Inventory.PurchaseInit',
    index=13,
    containing_service=None,
    input_type=_CINVENTORY_PURCHASEINIT_REQUEST,
    output_type=_CINVENTORY_PURCHASEINIT_RESPONSE,
    serialized_options=b'\202\265\030#Initializes a purchase for the user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PurchaseFinalize',
    full_name='Inventory.PurchaseFinalize',
    index=14,
    containing_service=None,
    input_type=_CINVENTORY_PURCHASEFINALIZE_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030!Finalizes a purchase for the user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InspectItem',
    full_name='Inventory.InspectItem',
    index=15,
    containing_service=None,
    input_type=_CINVENTORY_INSPECTITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    serialized_options=b'\202\265\030.Get item detail given a valid inspection token',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INVENTORY)

DESCRIPTOR.services_by_name['Inventory'] = _INVENTORY


_INVENTORYCLIENT = _descriptor.ServiceDescriptor(
  name='InventoryClient',
  full_name='InventoryClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\202\265\030-Client notifications inventory service events\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=4876,
  serialized_end=5072,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyNewItems',
    full_name='InventoryClient.NotifyNewItems',
    index=0,
    containing_service=None,
    input_type=_CINVENTORYCLIENT_NEWITEMS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030.Notify client that the user received new items',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INVENTORYCLIENT)

DESCRIPTOR.services_by_name['InventoryClient'] = _INVENTORYCLIENT

Inventory = service_reflection.GeneratedServiceType('Inventory', (_service.Service,), dict(
  DESCRIPTOR = _INVENTORY,
  __module__ = 'steammessages_inventory_pb2'
  ))

Inventory_Stub = service_reflection.GeneratedServiceStubType('Inventory_Stub', (Inventory,), dict(
  DESCRIPTOR = _INVENTORY,
  __module__ = 'steammessages_inventory_pb2'
  ))


InventoryClient = service_reflection.GeneratedServiceType('InventoryClient', (_service.Service,), dict(
  DESCRIPTOR = _INVENTORYCLIENT,
  __module__ = 'steammessages_inventory_pb2'
  ))

InventoryClient_Stub = service_reflection.GeneratedServiceStubType('InventoryClient_Stub', (InventoryClient,), dict(
  DESCRIPTOR = _INVENTORYCLIENT,
  __module__ = 'steammessages_inventory_pb2'
  ))


# @@protoc_insertion_point(module_scope)
